@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history.c,v 1.46.6.2 2004/11/14 11:49:06 chpe Exp $
+ *  $Id: ephy-history.c,v 1.48.10.1 2004/11/11 14:19:59 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -231,7 +231,7 @@ remove_obsolete_pages (EphyHistory *eb)
         g_date_set_time (&current_date, time (NULL));
 
 	children = ephy_node_get_children (eb->priv->pages);
-	for (i = (int) children->len -1; i >= 0; i--)
+	for (i = (int) children->len - 1; i >= 0; i--)
 	{
 		EphyNode *kid;
 
@@ -482,7 +482,6 @@ ephy_history_init (EphyHistory *eb)
 
 	/* Pages */
 	eb->priv->pages = ephy_node_new_with_id (db, PAGES_NODE_ID);
-	ephy_node_ref (eb->priv->pages);
 	g_value_init (&value, G_TYPE_STRING);
 	g_value_set_string (&value, _("All"));
 	ephy_node_set_property (eb->priv->pages,
@@ -513,7 +512,6 @@ ephy_history_init (EphyHistory *eb)
 
 	/* Hosts */
 	eb->priv->hosts = ephy_node_new_with_id (db, HOSTS_NODE_ID);
-	ephy_node_ref (eb->priv->hosts);
 	ephy_node_signal_connect_object (eb->priv->hosts,
 					 EPHY_NODE_CHILD_ADDED,
 				         (EphyNodeCallback) hosts_added_cb,
