@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-statusbar.h,v 1.3 2004/05/01 16:07:34 chpe Exp $
+ *  $Id: ephy-statusbar.h,v 1.4 2004/07/01 01:47:17 adamh Exp $
  */
 
 #ifndef EPHY_STATUSBAR_H
@@ -46,6 +46,7 @@ struct EphyStatusbar
 	/*< public >*/
 	GtkTooltips *tooltips;
 	GtkWidget *security_frame;
+	GtkWidget *popups_manager_frame;
 
 	/*< private >*/
         EphyStatusbarPrivate *priv;
@@ -64,6 +65,10 @@ void          ephy_statusbar_set_security_state		(EphyStatusbar *statusbar,
 							 gboolean secure,
 							 const char *tooltip);
 
+void          ephy_statusbar_set_popups_state		(EphyStatusbar *statusbar,
+							 gboolean hidden,
+							 const char *tooltip);
+
 void          ephy_statusbar_set_progress		(EphyStatusbar *statusbar,
 							 int progress);
 
